@@ -63,6 +63,10 @@ $(document).ready(function () {
           "kind": "block",
           "type": "turn_right"
         },
+        {
+          "kind": "block",
+          "type": "turn_around"
+        },
         {
           "kind": "block",
           "type": "pick_up"
@@ -73,6 +77,29 @@ $(document).ready(function () {
         },
       ]
     },
+    'BeginnerKarelCommands' : {
+      "kind": "category",
+      "name": "Наредбе роботу",
+      "colour": 295,
+      "contents": [
+        {
+          "kind": "block",
+          "type": "move",
+        },
+        {
+          "kind": "block",
+          "type": "turn_left"
+        },
+        {
+          "kind": "block",
+          "type": "turn_right"
+        },
+        {
+          "kind": "block",
+          "type": "pick_up"
+        },
+      ]
+    },
     'KarelBrain' :{
       "kind": "category",
       "name": "Питај робота",
@@ -291,6 +318,12 @@ $(document).ready(function () {
         drawer.drawFrame(robot.clone());
       };
       interpreter.setProperty(globalObject, 'turn_right', interpreter.createNativeFunction(wrapper));
+      wrapper = function () {
+        robot.turnRight();
+        robot.turnRight();
+        drawer.drawFrame(robot.clone());
+      };
+      interpreter.setProperty(globalObject, 'turn_around', interpreter.createNativeFunction(wrapper));
       wrapper = function () {
         robot.pickBall();
         drawer.drawFrame(robot.clone());
@@ -381,6 +414,7 @@ $(document).ready(function () {
     });
 
     karelCongrolosDiv.querySelector(".reset-button").addEventListener("click",function () {
+      workspace.getAllBlocks().forEach( a => a.setHighlighted(!1));
       clearError();
       reset();
     });
